@@ -3,33 +3,42 @@ import numpy as np
 from sklearn.preprocessing import StandardScaler, MinMaxScaler
 
 class Base:
-    def __init__(self, X, y, return_test, scale_X, scale_y, 
+    def __init__(self, X, y, Xnames, ynames, return_test, scale_X, scale_y, 
                 mean_normalize_y, noisy, test_train_ratio, s_to_n_ratio,
-                noise_variance, scaler='std', backend=None, link=None, name=None):
+                noise_variance, scaler, random_state, backend=None):
 
-        if backend:        
+        if backend is not None:        
             self.set_backend(backend)
 
         self.return_test = return_test
         self.X_test = None
+        self.Xnames = Xnames
+        self.ynames = ynames
 
-        if X is None:
-            pass
         assert len(X.shape) == 2, "X should have shape (*,*) but has "+str(X.shape)
         assert len(y.shape) == 2, "y should have shape (*,1) but has "+str(y.shape)
         assert y.shape[1] == 1, "y should have shape (*,1) but has "+str(y.shape)
         assert X.shape[0] == y.shape[0], "X and y must be of the same length"
         self.X = X
+        self.X_scaled = np.array(X)
         self.y = y
+        self.y_scaled = np.array(y)
         self.N = X.shape[0]
+
         if noisy:
+            np.random.seed(random_state)
             if s_to_n_ratio!=None and noise_variance!=None:
                 raise ValueError("set either s_to_n_ratio OR noise_variance")    
-            if s_to_n_ratio != None:
+            elif s_to_n_ratio != None:
                 var_y = np.var(y)
-            self.y_noisy = y + np.random.normal(0, var_y/s_to_n_ratio, (self.N, 1))
+                self.y_noisy = y + np.random.normal(0, var_y/s_to_n_ratio, (self.N, 1))
+            elif noise_variance!=None:
+                self.y_noisy = y + np.random.normal(0, noise_variance, (self.N, 1))
+            else:
+                raise ValueError("noisy=True but s_to_n_ratio or noise_variance not specified")
         else:
             self.y_noisy = y
+        self.y_noisy_scaled = np.array(self.y_noisy)
 
         if return_test:
             Min = X.min()
@@ -49,12 +58,12 @@ class Base:
         elif scale_y:
             self._scale_y(scaler)
         elif mean_normalize_y:
-            self._scale_y('std', with_std=False)
+            self._scale_y(scaler='std', with_std=False)
         else:
             raise ValueError("set either scale_y=True OR mean_normalize_y=True")
 
     def get_data(self):
-        return self.transform(self.X, self.y_noisy, self.X_test)
+        return self.transform(self.X_scaled, self.y_noisy_scaled, self.X_test_scaled)
 
     def transform(self, X, y, X_test):
         backend = self.get_backend()
@@ -96,9 +105,9 @@ class Base:
         else:
             raise NotImplementedError('scaler: '+scaler)
 
-        self.X = self.Xscaler.fit_transform(self.X)
+        self.X_scaled = self.Xscaler.fit_transform(self.X)
         if self.return_test:
-            self.X_test = self.Xscaler.transform(self.X_test)
+            self.X_test_scaled = self.Xscaler.transform(self.X_test)
 
     def _scale_y(self, scaler='std', with_mean=True, with_std=True, feature_range=(0,1)):
         """
@@ -111,14 +120,14 @@ class Base:
         else:
             raise NotImplementedError('scaler: '+scaler)
 
-        self.y = self.yscaler.fit_transform(self.y)
-        self.y_noisy = self.yscaler.transform(self.y_noisy)
+        self.y_scaled = self.yscaler.fit_transform(self.y)
+        self.y_noisy_scaled = self.yscaler.transform(self.y_noisy)
     
     def _plot(self, ax, **kwargs):
         ax.plot(self.X, self.y, label='True f')
         ax.scatter(self.X, self.y_noisy, label='data', **kwargs)
-        ax.set_xlabel('X')
-        ax.set_ylabel('y')
+        ax.set_xlabel(self.Xnames[0])
+        ax.set_ylabel(self.ynames[0])
         ax.legend()
         return ax
 
